==> aws-cdk.aws-ses-actions-1.144.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_ses_actions_LambdaInvocationType(p) {
}
function _aws_cdk_aws_ses_actions_EmailEncoding(p) {
}
function _aws_cdk_aws_ses_actions_AddHeaderProps(p) {
}
function _aws_cdk_aws_ses_actions_BounceTemplateProps(p) {
}
function _aws_cdk_aws_ses_actions_StopProps(p) {
}
function _aws_cdk_aws_ses_actions_BounceProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.template))
        _aws_cdk_aws_ses_actions_BounceTemplate(p.template);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ses_actions_SnsProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.encoding))
        _aws_cdk_aws_ses_actions_EmailEncoding(p.encoding);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ses_actions_S3Props(p) {
}
function _aws_cdk_aws_ses_actions_AddHeader(p) {
}
function _aws_cdk_aws_ses_actions_Lambda(p) {
}
function _aws_cdk_aws_ses_actions_Bounce(p) {
}
function _aws_cdk_aws_ses_actions_S3(p) {
}
function _aws_cdk_aws_ses_actions_Sns(p) {
}
function _aws_cdk_aws_ses_actions_Stop(p) {
}
function _aws_cdk_aws_ses_actions_LambdaProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.invocationType))
        _aws_cdk_aws_ses_actions_LambdaInvocationType(p.invocationType);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ses_actions_BounceTemplate(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_ses_actions_LambdaInvocationType, _aws_cdk_aws_ses_actions_EmailEncoding, _aws_cdk_aws_ses_actions_AddHeaderProps, _aws_cdk_aws_ses_actions_BounceTemplateProps, _aws_cdk_aws_ses_actions_StopProps, _aws_cdk_aws_ses_actions_BounceProps, _aws_cdk_aws_ses_actions_SnsProps, _aws_cdk_aws_ses_actions_S3Props, _aws_cdk_aws_ses_actions_AddHeader, _aws_cdk_aws_ses_actions_Lambda, _aws_cdk_aws_ses_actions_Bounce, _aws_cdk_aws_ses_actions_S3, _aws_cdk_aws_ses_actions_Sns, _aws_cdk_aws_ses_actions_Stop, _aws_cdk_aws_ses_actions_LambdaProps, _aws_cdk_aws_ses_actions_BounceTemplate };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-ses-actions-1.147.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_ses_actions_LambdaInvocationType(p) {
}
function _aws_cdk_aws_ses_actions_EmailEncoding(p) {
}
function _aws_cdk_aws_ses_actions_AddHeaderProps(p) {
}
function _aws_cdk_aws_ses_actions_BounceTemplateProps(p) {
}
function _aws_cdk_aws_ses_actions_StopProps(p) {
}
function _aws_cdk_aws_ses_actions_BounceProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.template))
        _aws_cdk_aws_ses_actions_BounceTemplate(p.template);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ses_actions_SnsProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.encoding))
        _aws_cdk_aws_ses_actions_EmailEncoding(p.encoding);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ses_actions_S3Props(p) {
}
function _aws_cdk_aws_ses_actions_AddHeader(p) {
}
function _aws_cdk_aws_ses_actions_Bounce(p) {
}
function _aws_cdk_aws_ses_actions_Lambda(p) {
}
function _aws_cdk_aws_ses_actions_S3(p) {
}
function _aws_cdk_aws_ses_actions_Stop(p) {
}
function _aws_cdk_aws_ses_actions_Sns(p) {
}
function _aws_cdk_aws_ses_actions_LambdaProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.invocationType))
        _aws_cdk_aws_ses_actions_LambdaInvocationType(p.invocationType);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ses_actions_BounceTemplate(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_ses_actions_LambdaInvocationType, _aws_cdk_aws_ses_actions_EmailEncoding, _aws_cdk_aws_ses_actions_AddHeaderProps, _aws_cdk_aws_ses_actions_BounceTemplateProps, _aws_cdk_aws_ses_actions_StopProps, _aws_cdk_aws_ses_actions_BounceProps, _aws_cdk_aws_ses_actions_SnsProps, _aws_cdk_aws_ses_actions_S3Props, _aws_cdk_aws_ses_actions_AddHeader, _aws_cdk_aws_ses_actions_Bounce, _aws_cdk_aws_ses_actions_Lambda, _aws_cdk_aws_ses_actions_S3, _aws_cdk_aws_ses_actions_Stop, _aws_cdk_aws_ses_actions_Sns, _aws_cdk_aws_ses_actions_LambdaProps, _aws_cdk_aws_ses_actions_BounceTemplate };
module.exports.DeprecationError = DeprecationError;
